import { ASTNode } from 'graphql/language';
import { CachedContent, GraphQLCache as GraphQLCacheInterface, GraphQLConfig as GraphQLConfigInterface, GraphQLFileMetadata, GraphQLFileInfo, FragmentInfo, ObjectTypeInfo, Uri, GraphQLProjectConfig } from 'graphql-language-service-types';
import { GraphQLSchema } from 'graphql';
import { GraphQLConfig, GraphQLEndpoint } from 'graphql-config';
export declare function getGraphQLCache(configDir: Uri): Promise<GraphQLCache>;
export declare class GraphQLCache implements GraphQLCacheInterface {
    _configDir: Uri;
    _graphQLFileListCache: Map<Uri, Map<string, GraphQLFileInfo>>;
    _graphQLConfig: GraphQLConfig;
    _schemaMap: Map<Uri, GraphQLSchema>;
    _typeExtensionMap: Map<Uri, number>;
    _fragmentDefinitionsCache: Map<Uri, Map<string, FragmentInfo>>;
    _typeDefinitionsCache: Map<Uri, Map<string, ObjectTypeInfo>>;
    constructor(configDir: Uri, graphQLConfig: GraphQLConfig);
    getGraphQLConfig: () => GraphQLConfigInterface;
    getFragmentDependencies: (query: string, fragmentDefinitions?: Map<string, FragmentInfo> | null | undefined) => Promise<FragmentInfo[]>;
    getFragmentDependenciesForAST: (parsedQuery: ASTNode, fragmentDefinitions: Map<string, FragmentInfo>) => Promise<FragmentInfo[]>;
    getFragmentDefinitions: (projectConfig: GraphQLProjectConfig) => Promise<Map<string, FragmentInfo>>;
    getObjectTypeDependencies: (query: string, objectTypeDefinitions?: Map<string, ObjectTypeInfo> | undefined) => Promise<ObjectTypeInfo[]>;
    getObjectTypeDependenciesForAST: (parsedQuery: ASTNode, objectTypeDefinitions: Map<string, ObjectTypeInfo>) => Promise<ObjectTypeInfo[]>;
    getObjectTypeDefinitions: (projectConfig: GraphQLProjectConfig) => Promise<Map<string, ObjectTypeInfo>>;
    _readFilesFromInputDirs: (rootDir: string, includes: string[]) => Promise<GraphQLFileMetadata[]>;
    _updateGraphQLFileListCache(graphQLFileMap: Map<Uri, GraphQLFileInfo>, metrics: {
        size: number;
        mtime: number;
    }, filePath: Uri, exists: boolean): Promise<Map<Uri, GraphQLFileInfo>>;
    updateFragmentDefinition(rootDir: Uri, filePath: Uri, contents: Array<CachedContent>): Promise<void>;
    updateFragmentDefinitionCache(rootDir: Uri, filePath: Uri, exists: boolean): Promise<void>;
    updateObjectTypeDefinition(rootDir: Uri, filePath: Uri, contents: Array<CachedContent>): Promise<void>;
    updateObjectTypeDefinitionCache(rootDir: Uri, filePath: Uri, exists: boolean): Promise<void>;
    _extendSchema(schema: GraphQLSchema, schemaPath: string | null, schemaCacheKey: string | null): GraphQLSchema;
    getSchema: (appName?: string | undefined, queryHasExtensions?: import("graphql/tsutils/Maybe").default<boolean>) => Promise<GraphQLSchema | null>;
    _invalidateSchemaCacheForProject(projectConfig: GraphQLProjectConfig): void;
    _getSchemaCacheKeysForProject(projectConfig: GraphQLProjectConfig): {
        endpointKey: string | null;
        schemaKey: string | null;
    };
    _getProjectName(projectConfig: GraphQLProjectConfig): GraphQLProjectConfig;
    _getDefaultEndpoint(projectConfig: GraphQLProjectConfig): {
        endpointName: string;
        endpoint: GraphQLEndpoint;
    } | null;
    readAllGraphQLFiles: (list: GraphQLFileMetadata[]) => Promise<{
        objectTypeDefinitions: Map<string, ObjectTypeInfo>;
        fragmentDefinitions: Map<string, FragmentInfo>;
        graphQLFileMap: Map<string, GraphQLFileInfo>;
    }>;
    processGraphQLFiles: (responses: GraphQLFileInfo[]) => {
        objectTypeDefinitions: Map<string, ObjectTypeInfo>;
        fragmentDefinitions: Map<string, FragmentInfo>;
        graphQLFileMap: Map<string, GraphQLFileInfo>;
    };
    promiseToReadGraphQLFile: (filePath: string) => Promise<GraphQLFileInfo>;
}
//# sourceMappingURL=GraphQLCache.d.ts.map