"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const os_1 = __importDefault(require("os"));
const path_1 = require("path");
const SEVERITY = {
    ERROR: 'ERROR',
    WARNING: 'WARNING',
    INFO: 'INFO',
    DEBUG: 'DEBUG',
};
class Logger {
    constructor() {
        const dir = path_1.join(os_1.default.tmpdir(), 'graphql-language-service-logs');
        try {
            if (!fs_1.default.existsSync(dir)) {
                fs_1.default.mkdirSync(dir);
            }
        }
        catch (_) {
        }
        this._logFilePath = path_1.join(dir, `graphql-language-service-log-${os_1.default.userInfo().username}-${getDateString()}.log`);
        this._stream = null;
    }
    error(message) {
        this._log(message, 'ERROR');
    }
    warn(message) {
        this._log(message, 'WARNING');
    }
    info(message) {
        this._log(message, 'INFO');
    }
    log(message) {
        this._log(message, 'DEBUG');
    }
    _log(message, severityKey = 'DEBUG') {
        const timestamp = new Date().toLocaleString(undefined);
        const severity = SEVERITY[severityKey];
        const pid = process.pid;
        const logMessage = `${timestamp} [${severity}] (pid: ${pid}) graphql-language-service-usage-logs: ${message}\n\n`;
        fs_1.default.appendFile(this._logFilePath, logMessage, _error => { });
    }
}
exports.Logger = Logger;
function getDateString() {
    const date = new Date();
    return `${date.getFullYear()}-${date.getMonth() + 1}-${date.getDate()}`;
}
//# sourceMappingURL=Logger.js.map