import { CachedContent, GraphQLCache, Uri } from 'graphql-language-service-types';
import { GraphQLLanguageService } from 'graphql-language-service-interface';
import { CompletionParams } from 'vscode-languageserver-protocol';
import { CompletionItem, CompletionList, CancellationToken, Hover, InitializeResult, Location, PublishDiagnosticsParams, DidChangeTextDocumentParams, DidCloseTextDocumentParams, DidChangeWatchedFilesParams, InitializeParams, VersionedTextDocumentIdentifier, DidSaveTextDocumentParams, TextDocumentPositionParams } from 'vscode-languageserver';
import { Logger } from './Logger';
declare type CachedDocumentType = {
    version: number;
    contents: CachedContent[];
};
export declare class MessageProcessor {
    _graphQLCache: GraphQLCache;
    _languageService: GraphQLLanguageService;
    _textDocumentCache: Map<string, CachedDocumentType>;
    _isInitialized: boolean;
    _willShutdown: boolean;
    _logger: Logger;
    constructor(logger: Logger);
    handleInitializeRequest(params: InitializeParams, _token?: CancellationToken, configDir?: string): Promise<InitializeResult>;
    handleDidOpenOrSaveNotification(params: DidSaveTextDocumentParams): Promise<PublishDiagnosticsParams | null>;
    handleDidChangeNotification(params: DidChangeTextDocumentParams): Promise<PublishDiagnosticsParams | null>;
    handleDidCloseNotification(params: DidCloseTextDocumentParams): void;
    handleShutdownRequest(): void;
    handleExitNotification(): void;
    validateDocumentAndPosition(params: CompletionParams): void;
    handleCompletionRequest(params: CompletionParams): Promise<CompletionList | Array<CompletionItem>>;
    handleHoverRequest(params: TextDocumentPositionParams): Promise<Hover>;
    handleWatchedFilesChangedNotification(params: DidChangeWatchedFilesParams): Promise<PublishDiagnosticsParams[] | null>;
    handleDefinitionRequest(params: TextDocumentPositionParams, _token?: CancellationToken): Promise<Array<Location>>;
    _isRelayCompatMode(query: string): boolean;
    _updateFragmentDefinition(uri: Uri, contents: CachedContent[]): Promise<void>;
    _updateObjectTypeDefinition(uri: Uri, contents: CachedContent[]): Promise<void>;
    _getCachedDocument(uri: string): CachedDocumentType | null;
    _invalidateCache(textDocument: VersionedTextDocumentIdentifier, uri: Uri, contents: CachedContent[]): void;
}
export declare function getQueryAndRange(text: string, uri: string): CachedContent[];
export {};
//# sourceMappingURL=MessageProcessor.d.ts.map