"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const graphql_language_service_utils_1 = require("graphql-language-service-utils");
function getLocator(source) {
    const offsetLine = 0;
    const offsetColumn = 0;
    const originalLines = source.split('\n');
    let start = 0;
    const lineRanges = originalLines.map((line, i) => {
        const end = start + line.length + 1;
        const range = { start, end, line: i };
        start = end;
        return range;
    });
    let i = 0;
    function rangeContains(range, index) {
        return range.start <= index && index < range.end;
    }
    function getLocation(range, index) {
        return {
            line: offsetLine + range.line,
            column: offsetColumn + index - range.start,
            character: index,
        };
    }
    function locateStr(search) {
        let range = lineRanges[i];
        const d = search >= range.end ? 1 : -1;
        while (range) {
            if (rangeContains(range, search)) {
                return getLocation(range, search);
            }
            i += d;
            range = lineRanges[i];
        }
        throw new Error('Location not found.');
    }
    return locateStr;
}
exports.getLocator = getLocator;
function locate(source, search) {
    return getLocator(source)(search);
}
exports.locate = locate;
exports.makeExtractTagsFromSource = (regexp) => (text) => {
    const locator = getLocator(text);
    const sources = [];
    let result;
    while ((result = regexp.exec(text)) !== null) {
        if (result) {
            const start = locator(result.index);
            const end = locator(result.index + result[0].length);
            sources.push({
                template: result[0],
                range: new graphql_language_service_utils_1.Range(new graphql_language_service_utils_1.Position(start.line, start.column), new graphql_language_service_utils_1.Position(end.line, end.column)),
            });
        }
    }
    regexp.lastIndex = 0;
    return [...sources];
};
//# sourceMappingURL=languageUtils.js.map