"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const graphql_language_service_utils_1 = require("graphql-language-service-utils");
const languageUtils_1 = require("./languageUtils");
const jsFileFilter = new RegExp(/graphql`|graphql\.experimental`|gql`/);
const jsGraphQLTagsRegexp = new RegExp(/(?<=(graphql|gql|graphql\.experimental)`)[\s\S]+?(?=`)/g);
const jsRemoveInterpolationRegexp = new RegExp(/([\s]+\${)[\s\S]+?(})/g);
const jsExtractor = languageUtils_1.makeExtractTagsFromSource(jsGraphQLTagsRegexp);
const reasonFileFilterRegexp = new RegExp(/(\[%(graphql|relay\.))/);
const reasonGraphQLTagsRegexp = new RegExp(/(?<=\[%(graphql|relay\.\w*)[\s\S]*{\|)[.\s\S]+?(?=\|})/g);
const reasonExtractor = languageUtils_1.makeExtractTagsFromSource(reasonGraphQLTagsRegexp);
const jsLanguages = {
    extensions: ['js', 'jsx', 'ts', 'tsx', 'mjs', 'es6'],
    fileFilter: (content) => jsFileFilter.test(content),
    extractSources: (content) => jsExtractor(content).map(source => (Object.assign(Object.assign({}, source), { template: source.template.replace(jsRemoveInterpolationRegexp, '') }))),
};
const graphql = {
    extensions: ['graphql', 'gql'],
    fileFilter: () => true,
    extractSources: (content) => {
        const lines = content.split('\n');
        const range = new graphql_language_service_utils_1.Range(new graphql_language_service_utils_1.Position(0, 0), new graphql_language_service_utils_1.Position(lines.length - 1, lines[lines.length - 1].length - 1));
        return [{ template: content, range }];
    },
};
const reasonML = {
    extensions: ['re'],
    fileFilter: (content) => reasonFileFilterRegexp.test(content),
    extractSources: reasonExtractor,
};
const languages = [jsLanguages, graphql, reasonML];
function registerLanguage(language) {
    languages.push(language);
}
exports.registerLanguage = registerLanguage;
function getLanguageFromExtension(ext) {
    return languages.find(language => language.extensions.find(e => e === ext));
}
exports.getLanguageFromExtension = getLanguageFromExtension;
//# sourceMappingURL=languages.js.map